<?php
/**
 * Function describe for AllBlog 
 * 
 * @package allblog
 */

/**
 * Set a constant that holds the theme's minimum supported PHP version.
 */
define( 'ALLBLOG_MIN_PHP_VERSION', '5.6' );

/**
 * Immediately after theme switch is fired we we want to check php version and
 * revert to previously active theme if version is below our minimum.
 */
add_action( 'after_switch_theme', 'allblog_test_for_min_php' );

/**
 * Switches back to the previous theme if the minimum PHP version is not met.
 */
function allblog_test_for_min_php() {

	// Compare versions.
	if ( version_compare( PHP_VERSION, ALLBLOG_MIN_PHP_VERSION, '<' ) ) {
		// Site doesn't meet themes min php requirements, add notice...
		add_action( 'admin_notices', 'allblog_min_php_not_met_notice' );
		// ... and switch back to previous theme.
		switch_theme( get_option( 'theme_switched' ) );
		return false;

	};
}

if ( ! function_exists( 'wp_body_open' ) ) {
        function wp_body_open() {
                do_action( 'wp_body_open' );
        }
}

/**
 * An error notice that can be displayed if the Minimum PHP version is not met.
 */
function allblog_min_php_not_met_notice() {
	?>
	<div class="notice notice-error is_dismissable">
		<p>
			<?php esc_html_e( 'You need to update your PHP version to run this theme.', 'allblog' ); ?> <br />
			<?php
			printf(
				/* translators: 1 is the current PHP version string, 2 is the minmum supported php version string of the theme */
				esc_html__( 'Actual version is: %1$s, required version is: %2$s.', 'allblog' ),
				PHP_VERSION,
				ALLBLOG_MIN_PHP_VERSION
			); // phpcs: XSS ok.
			?>
		</p>
	</div>
	<?php
}


add_action( 'wp_enqueue_scripts', 'allblog_enqueue_styles' );
function allblog_enqueue_styles() {

  wp_enqueue_style( 'allingrid-stylesheet', get_template_directory_uri() . '/style.css' );
	wp_enqueue_style( 'allblog-child-style', get_stylesheet_uri(), array( 'allblog-stylesheet' ) );
}
